add_object_info — MSUMastro toolbox 0.1 documentation

# add_object_info

`msumastro.header_processing.patchers.` `add_object_info`(directory=None, object_list=None, object_list_dir=None, match_radius=20.0, new_file_ext=None, save_location=None, overwrite=False, detailed_history=True)

  Add object information to FITS files that contain pointing information given a list of objects.

  Parameters: | directory : str Directory containing the FITS files to be fixed. Default is the current directory, `.`. object_list : str, optional Name of file containing list of objects. Default is set by `read_object_list()` which also explains the format of this file. object_list_dir : str, optional Directory in which the object_list is contained. Default is directory. match_radius : float, optional Maximum distance, in arcmin, between the RA/Dec of the image and a particular object for the image to be considered an image of that object. new_file_ext : str, optional Name added to the FITS files with updated header information. It is added to the base name of the input file, between the old file name and the .fit or .fits extension. Default is ‘new’. save_location : str, optional Directory to which the patched files should be written, if not dir. overwrite : bool, optional Set to True to replace the original files.